# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: virtual_cluster_size.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avirtual_cluster_size.proto\x12\x11\x63om.clickzetta.rm\"\xba\x01\n\x16VirtualClusterSizeSpec\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x07\x61lias_1\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61lias_2\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x61lias_3\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x08\x63pu_core\x18\x06 \x01(\x01\x12\x0e\n\x06mem_gb\x18\x07 \x01(\x03\x42\n\n\x08_alias_1B\n\n\x08_alias_2B\n\n\x08_alias_3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'virtual_cluster_size_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIRTUALCLUSTERSIZESPEC']._serialized_start=50
  _globals['_VIRTUALCLUSTERSIZESPEC']._serialized_end=236
# @@protoc_insertion_point(module_scope)
