# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: input_split.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import virtual_value_info_pb2 as virtual__value__info__pb2
from . import statistics_pb2 as statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11input_split.proto\x12\x08\x63z.proto\x1a\x18virtual_value_info.proto\x1a\x10statistics.proto\"\xc1\x01\n\nInputSplit\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.cz.proto.InputSplitType\x12\x12\n\noperatorId\x18\x02 \x01(\t\x12\x34\n\nfileRanges\x18\x03 \x01(\x0b\x32\x1e.cz.proto.FileRangesInputSplitH\x00\x12\x38\n\x0c\x66ileRowRange\x18\x04 \x01(\x0b\x32 .cz.proto.FileRowRangeInputSplitH\x00\x42\x07\n\x05split\"<\n\x0e\x46ileFieldStats\x12*\n\x0c\x66ield_ranges\x18\x01 \x03(\x0b\x32\x14.cz.proto.FieldRange\"\xe7\x01\n\tFileRange\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12.\n\nvalue_info\x18\x04 \x01(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12(\n\x0b\x64\x65lta_files\x18\x05 \x03(\x0b\x32\x13.cz.proto.FileRange\x12%\n\x04type\x18\x06 \x01(\x0e\x32\x17.cz.proto.FileRangeType\x12-\n\x0b\x66ield_stats\x18\x07 \x01(\x0b\x32\x18.cz.proto.FileFieldStats\"d\n\x14\x46ileRangesInputSplit\x12#\n\x06ranges\x18\x02 \x03(\x0b\x32\x13.cz.proto.FileRange\x12\x14\n\x0c\x62ucket_count\x18\x03 \x01(\r\x12\x11\n\tbucket_id\x18\x04 \x01(\r\"J\n\x16\x46ileRowRangeInputSplit\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tstart_row\x18\x02 \x01(\x03\x12\x0f\n\x07\x65nd_row\x18\x03 \x01(\x03\"\x95\x01\n\tRangeFile\x12\x11\n\x04path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\trecordCnt\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\x08\x66ileSize\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x15\n\x08location\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_pathB\x0c\n\n_recordCntB\x0b\n\t_fileSizeB\x0b\n\t_location\"K\n\x0cRangeLiteral\x12\x0e\n\x04intV\x18\x01 \x01(\x05H\x00\x12\x0f\n\x05longV\x18\x02 \x01(\x03H\x00\x12\x11\n\x07stringV\x18\x03 \x01(\tH\x00\x42\x07\n\x05value\"\xa9\x01\n\x0eRangePartition\x12\x14\n\x07rangeId\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\'\n\nrangeFiles\x18\x02 \x03(\x0b\x32\x13.cz.proto.RangeFile\x12%\n\x05lower\x18\x03 \x03(\x0b\x32\x16.cz.proto.RangeLiteral\x12%\n\x05upper\x18\x04 \x03(\x0b\x32\x16.cz.proto.RangeLiteralB\n\n\x08_rangeId\"#\n\x0fOutputSplitType\"\x10\n\x04Type\x12\x08\n\x04\x46ILE\x10\x00\"\x83\x01\n\x0bOutputSplit\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.cz.proto.OutputSplitType.Type\x12\x12\n\noperatorId\x18\x02 \x01(\t\x12)\n\x04\x66ile\x18\x04 \x01(\x0b\x32\x19.cz.proto.FileOutputSplitH\x00\x42\x07\n\x05split\"\x1f\n\x0f\x46ileOutputSplit\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x98\x01\n\rFileSplitMeta\x12\x12\n\nsplit_file\x18\x03 \x01(\t\x12.\n\x06offset\x18\x04 \x03(\x0b\x32\x1e.cz.proto.FileSplitMeta.Offset\x1a\x43\n\x06Offset\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x14\n\x0cstart_offset\x18\x02 \x01(\x03\x12\x12\n\nend_offset\x18\x03 \x01(\x03\"\xb0\x01\n\x11\x45mbeddedSplitMeta\x12\x30\n\x06splits\x18\x03 \x03(\x0b\x32 .cz.proto.EmbeddedSplitMeta.Pair\x1ai\n\x04Pair\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12#\n\x05split\x18\x02 \x01(\x0b\x32\x14.cz.proto.InputSplit\x12+\n\x0coutput_split\x18\x03 \x01(\x0b\x32\x15.cz.proto.OutputSplit\"\x97\x01\n\tSplitMeta\x12\x10\n\x08stage_id\x18\x01 \x01(\t\x12\x13\n\x0boperator_id\x18\x02 \x01(\t\x12\'\n\x04\x66ile\x18\x03 \x01(\x0b\x32\x17.cz.proto.FileSplitMetaH\x00\x12/\n\x08\x65mbedded\x18\x04 \x01(\x0b\x32\x1b.cz.proto.EmbeddedSplitMetaH\x00\x42\t\n\x07\x63ontent\"\xb6\x01\n\x13\x43ompactionSplitFile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\x0f\n\x07sliceId\x18\x04 \x01(\x03\x12.\n\nvalue_info\x18\x05 \x01(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12\x32\n\x0b\x64\x65lta_files\x18\x06 \x03(\x0b\x32\x1d.cz.proto.CompactionSplitFile\"?\n\x0f\x43ompactionSplit\x12,\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1d.cz.proto.CompactionSplitFile\"=\n\x10\x43ompactionSplits\x12)\n\x06splits\x18\x01 \x03(\x0b\x32\x19.cz.proto.CompactionSplit*/\n\x0eInputSplitType\x12\x0e\n\nFILE_RANGE\x10\x00\x12\r\n\tROW_RANGE\x10\x01*B\n\rFileRangeType\x12\x0f\n\x0bNORMAL_FILE\x10\x00\x12\x0e\n\nADDED_FILE\x10\x01\x12\x10\n\x0c\x44\x45LETED_FILE\x10\x02\x42\x13\x42\x0fInputSplitProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'input_split_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\017InputSplitProtoP\001'
  _globals['_INPUTSPLITTYPE']._serialized_start=2151
  _globals['_INPUTSPLITTYPE']._serialized_end=2198
  _globals['_FILERANGETYPE']._serialized_start=2200
  _globals['_FILERANGETYPE']._serialized_end=2266
  _globals['_INPUTSPLIT']._serialized_start=76
  _globals['_INPUTSPLIT']._serialized_end=269
  _globals['_FILEFIELDSTATS']._serialized_start=271
  _globals['_FILEFIELDSTATS']._serialized_end=331
  _globals['_FILERANGE']._serialized_start=334
  _globals['_FILERANGE']._serialized_end=565
  _globals['_FILERANGESINPUTSPLIT']._serialized_start=567
  _globals['_FILERANGESINPUTSPLIT']._serialized_end=667
  _globals['_FILEROWRANGEINPUTSPLIT']._serialized_start=669
  _globals['_FILEROWRANGEINPUTSPLIT']._serialized_end=743
  _globals['_RANGEFILE']._serialized_start=746
  _globals['_RANGEFILE']._serialized_end=895
  _globals['_RANGELITERAL']._serialized_start=897
  _globals['_RANGELITERAL']._serialized_end=972
  _globals['_RANGEPARTITION']._serialized_start=975
  _globals['_RANGEPARTITION']._serialized_end=1144
  _globals['_OUTPUTSPLITTYPE']._serialized_start=1146
  _globals['_OUTPUTSPLITTYPE']._serialized_end=1181
  _globals['_OUTPUTSPLITTYPE_TYPE']._serialized_start=1165
  _globals['_OUTPUTSPLITTYPE_TYPE']._serialized_end=1181
  _globals['_OUTPUTSPLIT']._serialized_start=1184
  _globals['_OUTPUTSPLIT']._serialized_end=1315
  _globals['_FILEOUTPUTSPLIT']._serialized_start=1317
  _globals['_FILEOUTPUTSPLIT']._serialized_end=1348
  _globals['_FILESPLITMETA']._serialized_start=1351
  _globals['_FILESPLITMETA']._serialized_end=1503
  _globals['_FILESPLITMETA_OFFSET']._serialized_start=1436
  _globals['_FILESPLITMETA_OFFSET']._serialized_end=1503
  _globals['_EMBEDDEDSPLITMETA']._serialized_start=1506
  _globals['_EMBEDDEDSPLITMETA']._serialized_end=1682
  _globals['_EMBEDDEDSPLITMETA_PAIR']._serialized_start=1577
  _globals['_EMBEDDEDSPLITMETA_PAIR']._serialized_end=1682
  _globals['_SPLITMETA']._serialized_start=1685
  _globals['_SPLITMETA']._serialized_end=1836
  _globals['_COMPACTIONSPLITFILE']._serialized_start=1839
  _globals['_COMPACTIONSPLITFILE']._serialized_end=2021
  _globals['_COMPACTIONSPLIT']._serialized_start=2023
  _globals['_COMPACTIONSPLIT']._serialized_end=2086
  _globals['_COMPACTIONSPLITS']._serialized_start=2088
  _globals['_COMPACTIONSPLITS']._serialized_end=2149
# @@protoc_insertion_point(module_scope)
