# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: file_meta_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import bucket_info_pb2 as bucket__info__pb2
from . import file_format_type_pb2 as file__format__type__pb2
from . import statistics_pb2 as statistics__pb2
from . import virtual_value_info_pb2 as virtual__value__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66ile_meta_data.proto\x12\x08\x63z.proto\x1a\x11\x62ucket_info.proto\x1a\x16\x66ile_format_type.proto\x1a\x10statistics.proto\x1a\x18virtual_value_info.proto\"+\n\tBlockInfo\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\x0e\n\x06length\x18\x02 \x01(\x04\"\xfb\x01\n\nDataLayout\x12#\n\x06\x66ooter\x18\x01 \x01(\x0b\x32\x13.cz.proto.BlockInfo\x12#\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x13.cz.proto.BlockInfo\x12%\n\x07\x62uckets\x18\x03 \x03(\x0b\x32\x14.cz.proto.BucketInfo\x12.\n\nvalue_info\x18\x04 \x03(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12\x1d\n\x10row_index_stride\x18\x05 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x10\x62lock_row_counts\x18\x06 \x03(\x03\x42\x13\n\x11_row_index_stride\"\x80\x01\n\x10\x45xtendedMetaData\x12;\n\tkey_value\x18\x01 \x03(\x0b\x32(.cz.proto.ExtendedMetaData.KeyValueEntry\x1a/\n\rKeyValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe9\x03\n\x0c\x46ileMetaData\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12-\n\x0b\x66ile_format\x18\x02 \x01(\x0e\x32\x18.cz.proto.FileFormatType\x12%\n\tfile_type\x18\x03 \x01(\x0e\x32\x12.cz.proto.FileType\x12\x15\n\rfile_slice_id\x18\x04 \x01(\x03\x12\x1a\n\x12\x66ile_slice_version\x18\x05 \x01(\x03\x12\x18\n\x10\x63ompaction_level\x18\x06 \x01(\x05\x12\x1c\n\x0f\x63luster_spec_id\x18\x07 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12sort_order_spec_id\x18\x08 \x01(\rH\x01\x88\x01\x01\x12 \n\x13primary_key_spec_id\x18\t \x01(\rH\x02\x88\x01\x01\x12$\n\x06layout\x18\n \x01(\x0b\x32\x14.cz.proto.DataLayout\x12\x35\n\x11\x65xtended_metadata\x18\x0b \x01(\x0b\x32\x1a.cz.proto.ExtendedMetaData\x12\"\n\x05stats\x18\x10 \x01(\x0b\x32\x13.cz.proto.StatsDataB\x12\n\x10_cluster_spec_idB\x15\n\x13_sort_order_spec_idB\x16\n\x14_primary_key_spec_id*;\n\x08\x46ileType\x12\x10\n\x0cUNKNOWN_FILE\x10\x00\x12\r\n\tDATA_FILE\x10\x01\x12\x0e\n\nDELTA_FILE\x10\x02\x42\x1f\n\x08\x63z.protoB\x11\x46ileMetaDataProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'file_meta_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\010cz.protoB\021FileMetaDataProtoP\001'
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._options = None
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._serialized_options = b'8\001'
  _globals['_FILETYPE']._serialized_start=1043
  _globals['_FILETYPE']._serialized_end=1102
  _globals['_BLOCKINFO']._serialized_start=121
  _globals['_BLOCKINFO']._serialized_end=164
  _globals['_DATALAYOUT']._serialized_start=167
  _globals['_DATALAYOUT']._serialized_end=418
  _globals['_EXTENDEDMETADATA']._serialized_start=421
  _globals['_EXTENDEDMETADATA']._serialized_end=549
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._serialized_start=502
  _globals['_EXTENDEDMETADATA_KEYVALUEENTRY']._serialized_end=549
  _globals['_FILEMETADATA']._serialized_start=552
  _globals['_FILEMETADATA']._serialized_end=1041
# @@protoc_insertion_point(module_scope)
