# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connection_meta.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63onnection_meta.proto\x12\x08\x63z.proto\"\x8b\x01\n\nConnection\x12\x31\n\x0f\x63onnection_type\x18\x01 \x01(\x0e\x32\x18.cz.proto.ConnectionType\x12\x39\n\x13\x63onnection_category\x18\x02 \x01(\x0e\x32\x1c.cz.proto.ConnectionCategory\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08*\x93\x01\n\x0e\x43onnectionType\x12\x12\n\x0e\x43LOUD_FUNCTION\x10\x00\x12\r\n\tLAKEHOUSE\x10\x01\x12\t\n\x05KAFKA\x10\x02\x12\x08\n\x04HIVE\x10\x03\x12\x0e\n\nCLICKHOUSE\x10\x04\x12\t\n\x05MYSQL\x10\x05\x12\x0b\n\x07POSTGRE\x10\x06\x12\r\n\tSQLSERVER\x10\x07\x12\x12\n\x0eOSS_CONNECTION\x10\x08*=\n\x12\x43onnectionCategory\x12\x13\n\x0f\x44\x41TA_CONNECTION\x10\x00\x12\x12\n\x0e\x41PI_CONNECTION\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connection_meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONNECTIONTYPE']._serialized_start=178
  _globals['_CONNECTIONTYPE']._serialized_end=325
  _globals['_CONNECTIONCATEGORY']._serialized_start=327
  _globals['_CONNECTIONCATEGORY']._serialized_end=388
  _globals['_CONNECTION']._serialized_start=36
  _globals['_CONNECTION']._serialized_end=175
# @@protoc_insertion_point(module_scope)
